@@ -1,5 +1,5 @@
 /* Seeed Grove ++ (C) 2015-2016 Stephane Charette <stephanecharette@gmail.com>
- * $Id: sg_8x8_CourierNew.cpp 1817 2016-05-01 00:18:10Z stephane $
+ * $Id: sg_8x8_CourierNew.cpp 1831 2016-05-06 16:25:21Z stephane $
  */
 
 #include "sg_8x8_CourierNew.hpp"
@@ -464,97 +464,96 @@ SG::Font::CourierNew::Fontmap SG::Font::CourierNew::get_fontmap(void) const
 					0,		0,		true,	true,	true,	0,		0,		0,
 					0,		0,		0,		0,		0,		0,		0,		0 } },
 
-#if 0
-		{ 'Q', {	0,		0,		0,		0,		0,		0,		0,		0,
-					0,		0,		0,		0,		0,		0,		0,		0,
-					0,		0,		0,		0,		0,		0,		0,		0,
-					0,		0,		0,		0,		0,		0,		0,		0,
-					0,		0,		0,		0,		0,		0,		0,		0,
-					0,		0,		0,		0,		0,		0,		0,		0,
-					0,		0,		0,		0,		0,		0,		0,		0,
+		{ 'Q', {	0,		0,		0,		true,	true,	true,	0,		0,
+					0,		0,		true,	0,		0,		0,		true,	0,
+					0,		0,		true,	0,		0,		0,		true,	0,
+					0,		0,		true,	0,		0,		0,		true,	0,
+					0,		0,		true,	0,		0,		0,		true,	0,
+					0,		0,		true,	0,		0,		0,		true,	0,
+					0,		0,		0,		true,	true,	true,	0,		0,
+					0,		0,		0,		0,		true,	true,	true,	0 } },
+
+		{ 'R', {	0,		0,		true,	true,	true,	true,	0,		0,
+					0,		0,		0,		true,	0,		0,		true,	0,
+					0,		0,		0,		true,	0,		0,		true,	0,
+					0,		0,		0,		true,	0,		0,		true,	0,
+					0,		0,		0,		true,	true,	true,	0,		0,
+					0,		0,		0,		true,	0,		0,		true,	0,
+					0,		0,		true,	true,	true,	0,		0,		true,
 					0,		0,		0,		0,		0,		0,		0,		0 } },
 
-		{ 'R', {	0,		0,		0,		0,		0,		0,		0,		0,
-					0,		0,		0,		0,		0,		0,		0,		0,
-					0,		0,		0,		0,		0,		0,		0,		0,
-					0,		0,		0,		0,		0,		0,		0,		0,
-					0,		0,		0,		0,		0,		0,		0,		0,
-					0,		0,		0,		0,		0,		0,		0,		0,
-					0,		0,		0,		0,		0,		0,		0,		0,
+		{ 'S', {	0,		0,		0,		true,	true,	0,		true,	0,
+					0,		0,		true,	0,		0,		true,	true,	0,
+					0,		0,		true,	0,		0,		0,		0,		0,
+					0,		0,		0,		true,	true,	true,	0,		0,
+					0,		0,		0,		0,		0,		0,		true,	0,
+					0,		0,		true,	0,		0,		0,		true,	0,
+					0,		0,		true,	true,	true,	true,	0,		0,
 					0,		0,		0,		0,		0,		0,		0,		0 } },
 
-		{ 'S', {	0,		0,		0,		0,		0,		0,		0,		0,
-					0,		0,		0,		0,		0,		0,		0,		0,
-					0,		0,		0,		0,		0,		0,		0,		0,
-					0,		0,		0,		0,		0,		0,		0,		0,
-					0,		0,		0,		0,		0,		0,		0,		0,
-					0,		0,		0,		0,		0,		0,		0,		0,
-					0,		0,		0,		0,		0,		0,		0,		0,
+		{ 'T', {	0,		0,		true,	true,	true,	true,	true,	0,
+					0,		0,		true,	0,		true,	0,		true,	0,
+					0,		0,		0,		0,		true,	0,		0,		0,
+					0,		0,		0,		0,		true,	0,		0,		0,
+					0,		0,		0,		0,		true,	0,		0,		0,
+					0,		0,		0,		0,		true,	0,		0,		0,
+					0,		0,		0,		true,	true,	true,	0,		0,
 					0,		0,		0,		0,		0,		0,		0,		0 } },
 
-		{ 'T', {	0,		0,		0,		0,		0,		0,		0,		0,
-					0,		0,		0,		0,		0,		0,		0,		0,
-					0,		0,		0,		0,		0,		0,		0,		0,
-					0,		0,		0,		0,		0,		0,		0,		0,
-					0,		0,		0,		0,		0,		0,		0,		0,
-					0,		0,		0,		0,		0,		0,		0,		0,
-					0,		0,		0,		0,		0,		0,		0,		0,
+		{ 'U', {	0,		true,	true,	true,	0,		true,	true,	true,
+					0,		0,		true,	0,		0,		0,		true,	0,
+					0,		0,		true,	0,		0,		0,		true,	0,
+					0,		0,		true,	0,		0,		0,		true,	0,
+					0,		0,		true,	0,		0,		0,		true,	0,
+					0,		0,		true,	0,		0,		0,		true,	0,
+					0,		0,		0,		true,	true,	true,	0,		0,
 					0,		0,		0,		0,		0,		0,		0,		0 } },
 
-		{ 'U', {	0,		0,		0,		0,		0,		0,		0,		0,
-					0,		0,		0,		0,		0,		0,		0,		0,
-					0,		0,		0,		0,		0,		0,		0,		0,
-					0,		0,		0,		0,		0,		0,		0,		0,
-					0,		0,		0,		0,		0,		0,		0,		0,
-					0,		0,		0,		0,		0,		0,		0,		0,
-					0,		0,		0,		0,		0,		0,		0,		0,
+		{ 'V', {	0,		true,	true,	true,	0,		true,	true,	true,
+					0,		0,		true,	0,		0,		0,		true,	0,
+					0,		0,		true,	0,		0,		0,		true,	0,
+					0,		0,		true,	0,		0,		true,	0,		0,
+					0,		0,		0,		true,	0,		true,	0,		0,
+					0,		0,		0,		true,	0,		true,	0,		0,
+					0,		0,		0,		true,	true,	0,		0,		0,
 					0,		0,		0,		0,		0,		0,		0,		0 } },
 
-		{ 'V', {	0,		0,		0,		0,		0,		0,		0,		0,
-					0,		0,		0,		0,		0,		0,		0,		0,
-					0,		0,		0,		0,		0,		0,		0,		0,
-					0,		0,		0,		0,		0,		0,		0,		0,
-					0,		0,		0,		0,		0,		0,		0,		0,
-					0,		0,		0,		0,		0,		0,		0,		0,
-					0,		0,		0,		0,		0,		0,		0,		0,
+		{ 'W', {	0,		true,	true,	true,	0,		true,	true,	true,
+					0,		0,		true,	0,		0,		0,		true,	0,
+					0,		0,		true,	0,		true,	0,		true,	0,
+					0,		0,		true,	0,		true,	0,		true,	0,
+					0,		0,		true,	0,		true,	0,		true,	0,
+					0,		0,		true,	0,		true,	0,		true,	0,
+					0,		0,		0,		true,	0,		true,	0,		0,
 					0,		0,		0,		0,		0,		0,		0,		0 } },
 
-		{ 'W', {	0,		0,		0,		0,		0,		0,		0,		0,
-					0,		0,		0,		0,		0,		0,		0,		0,
-					0,		0,		0,		0,		0,		0,		0,		0,
-					0,		0,		0,		0,		0,		0,		0,		0,
-					0,		0,		0,		0,		0,		0,		0,		0,
-					0,		0,		0,		0,		0,		0,		0,		0,
-					0,		0,		0,		0,		0,		0,		0,		0,
+		{ 'X', {	0,		true,	true,	0,		0,		0,		true,	true,
+					0,		0,		true,	0,		0,		0,		true,	0,
+					0,		0,		0,		true,	0,		true,	0,		0,
+					0,		0,		0,		0,		true,	0,		0,		0,
+					0,		0,		0,		true,	0,		true,	0,		0,
+					0,		0,		true,	0,		0,		0,		true,	0,
+					0,		true,	true,	0,		0,		0,		true,	true,
 					0,		0,		0,		0,		0,		0,		0,		0 } },
 
-		{ 'X', {	0,		0,		0,		0,		0,		0,		0,		0,
-					0,		0,		0,		0,		0,		0,		0,		0,
-					0,		0,		0,		0,		0,		0,		0,		0,
-					0,		0,		0,		0,		0,		0,		0,		0,
-					0,		0,		0,		0,		0,		0,		0,		0,
-					0,		0,		0,		0,		0,		0,		0,		0,
-					0,		0,		0,		0,		0,		0,		0,		0,
+		{ 'Y', {	0,		true,	true,	true,	0,		true,	true,	true,
+					0,		0,		true,	0,		0,		0,		true,	0,
+					0,		0,		0,		true,	0,		true,	0,		0,
+					0,		0,		0,		0,		true,	0,		0,		0,
+					0,		0,		0,		0,		true,	0,		0,		0,
+					0,		0,		0,		0,		true,	0,		0,		0,
+					0,		0,		0,		true,	true,	true,	0,		0,
 					0,		0,		0,		0,		0,		0,		0,		0 } },
 
-		{ 'Y', {	0,		0,		0,		0,		0,		0,		0,		0,
-					0,		0,		0,		0,		0,		0,		0,		0,
-					0,		0,		0,		0,		0,		0,		0,		0,
-					0,		0,		0,		0,		0,		0,		0,		0,
-					0,		0,		0,		0,		0,		0,		0,		0,
-					0,		0,		0,		0,		0,		0,		0,		0,
-					0,		0,		0,		0,		0,		0,		0,		0,
+		{ 'Z', {	0,		0,		true,	true,	true,	true,	true,	0,
+					0,		0,		true,	0,		0,		0,		true,	0,
+					0,		0,		0,		0,		0,		true,	0,		0,
+					0,		0,		0,		0,		true,	0,		0,		0,
+					0,		0,		0,		true,	0,		0,		0,		0,
+					0,		0,		true,	0,		0,		0,		true,	0,
+					0,		0,		true,	true,	true,	true,	true,	0,
 					0,		0,		0,		0,		0,		0,		0,		0 } },
-
-		{ 'Z', {	0,		0,		0,		0,		0,		0,		0,		0,
-					0,		0,		0,		0,		0,		0,		0,		0,
-					0,		0,		0,		0,		0,		0,		0,		0,
-					0,		0,		0,		0,		0,		0,		0,		0,
-					0,		0,		0,		0,		0,		0,		0,		0,
-					0,		0,		0,		0,		0,		0,		0,		0,
-					0,		0,		0,		0,		0,		0,		0,		0,
-					0,		0,		0,		0,		0,		0,		0,		0 } },
-
+/// @todo finish Courier New
 		{ '[', {	0,		0,		0,		0,		0,		0,		0,		0,
 					0,		0,		0,		0,		0,		0,		0,		0,
 					0,		0,		0,		0,		0,		0,		0,		0,
@@ -869,7 +868,7 @@ SG::Font::CourierNew::Fontmap SG::Font::CourierNew::get_fontmap(void) const
 					0,		0,		0,		0,		0,		0,		0,		0,
 					0,		0,		0,		0,		0,		0,		0,		0,
 					0,		0,		0,		0,		0,		0,		0,		0 } },
-#endif
+
 		{ '~', {	0,		0,		0,		0,		0,		0,		0,		0,
 					0,		0,		0,		0,		0,		0,		0,		0,
 					0,		0,		0,		0,		0,		0,		0,		0,
