@@ -1,5 +1,5 @@
 /* Seeed Grove ++ (C) 2015-2016 Stephane Charette <stephanecharette@gmail.com>
- * $Id: sg_101020011_TemperatureAndHumiditySensor.cpp 1729 2016-03-30 07:04:48Z stephane $
+ * $Id: sg_101020011_TemperatureAndHumiditySensor.cpp 1739 2016-04-04 07:42:44Z stephane $
  */
 
 #include "sg_101020011_TemperatureAndHumiditySensor.hpp"
@@ -15,7 +15,7 @@ SG::TemperatureAndHumiditySensor::~TemperatureAndHumiditySensor( void )
 
 
 SG::TemperatureAndHumiditySensor::TemperatureAndHumiditySensor( const std::string &n ) :
-		GroveI2C( SG::EGroveType::kTemperatureAndHumiditySensor, n )
+		GroveI2CAnalog( SG::EGroveType::kTemperatureAndHumiditySensor, n )
 {
 //	SG::SGpp::get().gpio.gpio_export( 2, GpioManagement::EDirection::kOutput );
 
@@ -24,7 +24,7 @@ SG::TemperatureAndHumiditySensor::TemperatureAndHumiditySensor( const std::strin
 
 
 SG::TemperatureAndHumiditySensor::TemperatureAndHumiditySensor( const SG::TemperatureAndHumiditySensor &rhs ) :
-		GroveI2C( rhs.get_type(), rhs.get_name() )
+		GroveI2CAnalog( rhs.get_type(), rhs.get_name() )
 {
 	return;
 }
