@@ -1,15 +1,15 @@
 /* Seeed Grove ++ (C) 2015-2016 Stephane Charette <stephanecharette@gmail.com>
- * $Id: sg_101020011_TemperatureAndHumiditySensor.hpp 1729 2016-03-30 07:04:48Z stephane $
+ * $Id: sg_101020011_TemperatureAndHumiditySensor.hpp 1739 2016-04-04 07:42:44Z stephane $
  */
 
 #pragma once
 
-#include "sg_GroveI2C.hpp"
+#include "sg_GroveI2CAnalog.hpp"
 
 
 namespace SG
 {
-	/** Temperature and humidity sensor.
+	/** Temperature and humidity sensor.  This is an analog sensor which needs to be connected to the @ref I2CADC.
 	 *
 	 * Description | Image
 	 * ------------|------
@@ -19,7 +19,7 @@ namespace SG
 	 * @see http://www.seeedstudio.com/wiki/Grove_-_Temperature_and_Humidity_Sensor
 	 * @see http://www.seeedstudio.com/depot/Grove-TempHumi-Sensor-p-745.html
 	 */
-	class TemperatureAndHumiditySensor : public GroveI2C
+	class TemperatureAndHumiditySensor : public GroveI2CAnalog
 	{
 		public:
 
