@@ -1,5 +1,5 @@
 /* Seeed Grove ++ (C) 2015-2016 Stephane Charette <stephanecharette@gmail.com>
- * $Id: sg_GroveGPIO.cpp 1512 2016-01-01 09:06:13Z stephane $
+ * $Id: sg_GroveGPIO.cpp 1852 2016-05-21 15:28:41Z stephane $
  */
 
 #include "sg_GroveGPIO.hpp"
@@ -20,6 +20,20 @@ SG::GroveGPIO::~GroveGPIO( void )
 }
 
 
+SG::GroveGPIO &SG::GroveGPIO::send_2_bytes( uint16_t bits )
+{
+	// break up the 16 bits into 2 bytes
+
+	const uint8_t byte1 = (bits >> 8) & 0xff;
+	const uint8_t byte2 = (bits >> 0) & 0xff;
+
+	send_byte( byte1 );
+	send_byte( byte2 );
+
+	return *this;
+}
+
+
 SG::GroveGPIO &SG::GroveGPIO::send_byte( uint8_t byte )
 {
 	// inspiration for this function came from http://www.seeedstudio.com/wiki/Grove_-_Chainable_RGB_LED#With_Beaglebone_Green
