@@ -1,5 +1,5 @@
 /* Seeed Grove ++ (C) 2015-2016 Stephane Charette <stephanecharette@gmail.com>
- * $Id: sg_MotionSensing.hpp 1729 2016-03-30 07:04:48Z stephane $
+ * $Id: sg_MotionSensing.hpp 1866 2016-05-28 04:22:15Z stephane $
  */
 
 #pragma once
@@ -8,4 +8,4 @@
 
 // http://www.seeedstudio.com/wiki/Grove_System#Motion_Sensing
 
-// nothing here yet
+#include "sg_101020034_3AxisCompass.hpp"
