@@ -1,5 +1,5 @@
 /* Seeed Grove ++ (C) 2015-2016 Stephane Charette <stephanecharette@gmail.com>
- * $Id: sg_UserInterface.hpp 1753 2016-04-10 22:29:30Z stephane $
+ * $Id: sg_UserInterface.hpp 1886 2016-06-01 05:35:45Z stephane $
  */
 
 #pragma once
@@ -8,7 +8,10 @@
 
 // http://www.seeedstudio.com/wiki/Grove_System#User_Interface
 
+#include "sg_101020003_Button.hpp"
 #include "sg_103020013_I2CADC.hpp"
+#include "sg_104020006_LEDBar.hpp"
+#include "sg_104030001_LCDRGBBacklight.hpp"
 #include "sg_104030006_ChainableRGBLED.hpp"
 #include "sg_104030008_OLED112.hpp"
 #include "sg_104030011_OLED096.hpp"
