@@ -1,5 +1,5 @@
 /* Seeed Grove ++ (C) 2015-2016 Stephane Charette <stephanecharette@gmail.com>
- * $Id: sg_all_groves.hpp 1729 2016-03-30 07:04:48Z stephane $
+ * $Id: sg_all_groves.hpp 1739 2016-04-04 07:42:44Z stephane $
  */
 
 #pragma once
@@ -9,6 +9,8 @@
 #include "sg_groves.hpp"
 #include "sg_GroveBase.hpp"
 #include "sg_GroveI2C.hpp"
+#include "sg_GroveI2CAnalog.hpp"
+#include "sg_GroveI2CDigital.hpp"
 #include "sg_GroveUART.hpp"
 #include "sg_GroveGPIO.hpp"
 
