@@ -1,8 +1,9 @@
 /* Seeed Grove ++ (C) 2015-2016 Stephane Charette <stephanecharette@gmail.com>
- * $Id: sg_groves.cpp 1512 2016-01-01 09:06:13Z stephane $
+ * $Id: sg_groves.cpp 1741 2016-04-06 01:17:28Z stephane $
  */
 
 #include "sg_groves.hpp"
+#include "sg_all_groves.hpp"
 
 
 uint32_t SG::get_sku_from_grove_type( const SG::EGroveType &grove_type )
@@ -391,72 +392,6 @@ std::string SG::to_string( const SG::EGroveType &type )
 }
 
 
-SG::MGroveTypeI2CAddresses SG::get_grove_type_addresses( void )
-{
-	// initially populated using the information at http://www.seeedstudio.com/wiki/I2C_And_I2C_Address_of_Seeed_Product
-
-	const MGroveTypeI2CAddresses m =
-	{
-		{ EGroveType::kMultichannelGasSensor			, 0x04 },
-		{ EGroveType::kI2CMotorDriverV10				, 0x0f },
-		{ EGroveType::kI2CMotorDriverV12				, 0x0f },
-		{ EGroveType::kI2CFMReceiver					, 0x10 },
-		{ EGroveType::k3AxisDigitalAccelerometer400g	, 0x18 },
-		{ EGroveType::kQTouchSensor						, 0x1b },
-		{ EGroveType::k3AxisDigitalCompass				, 0x1e },
-		{ EGroveType::k6AxisAccelerometerAndCompassV1	, 0x1e },
-		{ EGroveType::k6AxisAccelerometerAndCompassV2	, 0x1e },
-		{ EGroveType::kDigitalLightSensor				, 0x29 },
-		{ EGroveType::kI2CColorSensor					, 0x39 },
-		{ EGroveType::kOLEDDisplay0_96					, 0x3c },
-		{ EGroveType::kOLEDDisplay1_12					, 0x3c },
-		{ EGroveType::k3AxisDigitalCompass				, 0x3c },
-		{ EGroveType::kLCDRGBBacklight					, 0x3e },
-		{ EGroveType::kTemperatureAndHumiditySensor		, 0x40 },
-		{ EGroveType::k3AxisDigitalAccelerometer1_5g	, 0x4c },
-		{ EGroveType::k3AxisDigitalAccelerometer16g		, 0x53 },
-		{ EGroveType::kNFCTag							, 0x53 },
-		{ EGroveType::kTouchSensor						, 0x5a },
-		{ EGroveType::kTouchSensor						, 0x5b },
-		{ EGroveType::kDigitalInfraredTemperatureSensor	, 0x5b },
-		{ EGroveType::kTouchSensor						, 0x5c },
-		{ EGroveType::kTouchSensor						, 0x5d },
-		{ EGroveType::kLCDRGBBacklight					, 0x62 },
-		{ EGroveType::kRTC								, 0x68 },
-		{ EGroveType::k3AxisDigitalGyro					, 0x68 },
-		{ EGroveType::kIMU9DOFV1						, 0x68 },
-		{ EGroveType::kIMU9DOFV2						, 0x68 },
-		{ EGroveType::kIMU10DOF							, 0x68 },
-		{ EGroveType::kGestureV1						, 0x73 },
-		{ EGroveType::kBarometerHighAccuracy			, 0x76 },
-		{ EGroveType::kBarometerSensor					, 0x77 },
-		{ EGroveType::kBarometerSensorBMP180			, 0x77 },
-		{ EGroveType::kIMU9DOFV1						, 0x77 },
-		{ EGroveType::kIMU9DOFV2						, 0x77 },
-		{ EGroveType::kIMU10DOF							, 0x77 }
-	};
-
-	return m;
-}
-
-
-SG::VI2CAddresses SG::get_grove_type_addresses( const SG::EGroveType &type )
-{
-	const MGroveTypeI2CAddresses m = get_grove_type_addresses();
-
-	VI2CAddresses v;
-	auto ret = m.equal_range( type );
-	for ( auto	iter  = ret.first;
-				iter != ret.second;
-				iter ++ )
-	{
-		v.push_back( iter->second );
-	}
-
-	return v;
-}
-
-
 SG::VGroveTypes SG::detect( void )
 {
 	VGroveTypes v;
