@@ -1,15 +1,12 @@
 /* Seeed Grove ++ (C) 2015-2016 Stephane Charette <stephanecharette@gmail.com>
- * $Id: sg_groves.hpp 1731 2016-03-31 13:10:51Z stephane $
+ * $Id: sg_groves.hpp 1741 2016-04-06 01:17:28Z stephane $
  */
 
 #pragma once
 
 // Central include file for SeeedGrove++ is "sg++.hpp".
 
-#include <string>
-#include <vector>
-#include <map>
-#include <set>
+#include "sg_types.hpp"
 
 
 namespace SG
@@ -401,20 +398,5 @@ namespace SG
 	/// Get a short text name for the given type.
 	std::string to_string( const EGroveType &type );
 
-	/// I2C address for Seeed Grove products.
-	typedef uint8_t I2CAddress;
-
-	/// Map specific Grove type to a I2C address.  Note that some types have multiple addresses.
-	typedef std::multimap<EGroveType, I2CAddress> MGroveTypeI2CAddresses;
-
-	/// Vector of I2C addresses.
-	typedef std::vector<I2CAddress> VI2CAddresses;
-
-	/// Get a map of all known Grove types and their I2C address.  @see http://www.seeedstudio.com/wiki/I2C_And_I2C_Address_of_Seeed_Product
-	MGroveTypeI2CAddresses get_grove_type_addresses( void );
-
-	/// Get all the known addresses for a given Grove type.
-	VI2CAddresses get_grove_type_addresses( const EGroveType &type );
-	
 	VGroveTypes detect( void );
 }
