@@ -1,5 +1,5 @@
 /* Seeed Grove ++ (C) 2015-2016 Stephane Charette <stephanecharette@gmail.com>
- * $Id: seeedgrove.cpp 1820 2016-05-03 23:03:03Z stephane $
+ * $Id: seeedgrove.cpp 1867 2016-05-28 08:09:05Z stephane $
  */
 
 #include "sg++.hpp"
@@ -10,6 +10,7 @@
 #include <csignal>
 #include <cstring>
 #include <system_error>
+#include <cmath>
 
 
 typedef std::vector<std::string> VStr;
@@ -215,6 +216,92 @@ void temperature( const VStr &args )
 }
 
 
+void compass( const VStr &args )
+{
+	SG::ThreeAxisDigitalCompass three_axis_digital_compass;
+	std::cout << "3-axis digital compass: resetting configuration..." << std::endl;
+	three_axis_digital_compass.reset();
+
+	// MODE
+	SG::ThreeAxisDigitalCompass::EMode mode = three_axis_digital_compass.get_mode();
+	std::cout << "3-axis digital compass: mode = " << three_axis_digital_compass.to_string(mode) << std::endl;
+	std::cout << "Setting the mode to kIdle..." << std::endl;
+	three_axis_digital_compass.set_mode( SG::ThreeAxisDigitalCompass::EMode::kIdle );
+	mode = three_axis_digital_compass.get_mode();
+	std::cout << "3-axis digital compass: mode = " << three_axis_digital_compass.to_string(mode) << std::endl;
+
+	// GAIN
+	SG::ThreeAxisDigitalCompass::EGain gain;
+	three_axis_digital_compass.get_config( gain );
+	std::cout << "3-axis digital compass: gain = " << three_axis_digital_compass.to_string(gain) << std::endl;
+	std::cout << "Setting the gain to 4.0Ga..." << std::endl;
+	three_axis_digital_compass.set_config( SG::ThreeAxisDigitalCompass::EGain::k4_0Ga );
+	three_axis_digital_compass.get_config( gain );
+	std::cout << "3-axis digital compass: gain = " << three_axis_digital_compass.to_string(gain) << std::endl;
+
+	// OUTPUT RATE + MEASUREMENTS
+	SG::ThreeAxisDigitalCompass::EDataOutputRate	output_rate;
+	SG::ThreeAxisDigitalCompass::EMeasurements		measurements;
+	three_axis_digital_compass.get_config( output_rate, measurements );
+	std::cout << "3-axis digital compass: output rate = " << three_axis_digital_compass.to_string(output_rate)	<< std::endl;
+	std::cout << "3-axis digital compass: measurement = " << three_axis_digital_compass.to_string(measurements)	<< std::endl;
+	std::cout << "Changing output rate and measurement..." << std::endl;
+	three_axis_digital_compass.set_config( SG::ThreeAxisDigitalCompass::EDataOutputRate::k30Hz, SG::ThreeAxisDigitalCompass::EMeasurements::kPositiveBias );
+	three_axis_digital_compass.get_config( output_rate, measurements );
+	std::cout << "3-axis digital compass: output rate = " << three_axis_digital_compass.to_string(output_rate)	<< std::endl;
+	std::cout << "3-axis digital compass: measurement = " << three_axis_digital_compass.to_string(measurements)	<< std::endl;
+
+	bool regulator_enabled	= false;
+	bool data_locked		= false;
+	bool data_ready			= false;
+	three_axis_digital_compass.get_status( regulator_enabled, data_locked, data_ready );
+	std::cout << "Status: regulator=" << regulator_enabled << ", locked=" << data_locked << ", ready=" << data_ready << std::endl;
+
+	three_axis_digital_compass.reset();
+
+	int16_t x = 0;
+	int16_t y = 0;
+	int16_t z = 0;
+
+	while (exit_signal_detected == 0)
+	{
+		three_axis_digital_compass.wait_for_significant_change( x, y, z );
+
+		std::cout	<< "Data: "
+					<< "x=" << x << ", "
+					<< "y=" << y << ", "
+					<< "z=" << z << ", "
+					<< "direction="	<< three_axis_digital_compass.get_direction()	<< " radians, "
+					<< "heading="	<< three_axis_digital_compass.get_heading()		<< " degrees"
+					<< std::endl;
+	}
+
+	return;
+}
+
+
+void bb_detect( const VStr &args )
+{
+	std::cout << "BeagleBone detection:" << std::endl;
+
+	std::cout << "Device model name: " << SG::BeagleBone::Detect::get_model() << std::endl;
+
+	const SG::BeagleBone::Detect::Compatibilities compatibilities = SG::BeagleBone::Detect::get_compatibilities();
+	std::cout << "Number of compatibilities: " << compatibilities.size() << std::endl;
+	for ( const auto type : compatibilities )
+	{
+		std::cout << "- " << SG::BeagleBone::Detect::to_string(type) << std::endl;
+	}
+
+	std::cout
+			<< "BeagleBone compatible: "		<< SG::BeagleBone::Detect::is_beaglebone_compatible()		<< std::endl
+			<< "BeagleBone Black compatible: "	<< SG::BeagleBone::Detect::is_beaglebone_black_compatible()	<< std::endl
+			<< "BeagleBone Green compatible: "	<< SG::BeagleBone::Detect::is_beaglebone_green_compatible()	<< std::endl;
+
+	return;
+}
+
+
 void bb_led( const VStr &args )
 {
 	SG::BeagleBone::LEDControl led_control;
@@ -287,6 +374,38 @@ void bb_watchdog( const VStr &args )
 }
 
 
+void bb_usb( const VStr &args )
+{
+	if (args.size() == 1 && args[0] == "on")
+	{
+		std::cout << "Turning ON power to the USB port." << std::endl;
+		SG::BeagleBone::USB::turn_on();
+	}
+	else if (args.size() == 1 && args[0] == "off")
+	{
+		std::cout << "Turning OFF power to the USB port." << std::endl;
+		SG::BeagleBone::USB::turn_off();
+	}
+	else
+	{
+		std::cout << "Toggling USB power." << std::endl;
+		SG::BeagleBone::USB::toggle( 500 );
+		std::cout << "...pausing..." << std::endl;
+		std::this_thread::sleep_for( std::chrono::seconds(5) );
+
+		SG::BeagleBone::USB::turn_off();
+		std::cout << "USB power should now be off." << std::endl;
+		std::cout << "...pausing..." << std::endl;
+		std::this_thread::sleep_for( std::chrono::seconds(5) );
+
+		SG::BeagleBone::USB::turn_on();
+		std::cout << "USB power should now be on." << std::endl;
+	}
+
+	return;
+}
+
+
 void common_oled( SG::CommonOLED &oled, const VStr &args )
 {
 	std::cout << "working with " << oled.get_description() << std::endl;
@@ -335,6 +454,65 @@ void oled096( const VStr &args )
 }
 
 
+void ledbar( const VStr &args )
+{
+	SG::LEDBar led_bar;
+
+	if (args.size() == 0 || (args.size() == 1 && args[0] == "on"))
+	{
+		std::cout << "Turning ON LED bar." << std::endl;
+		led_bar.all_on();
+	}
+	else if (args.size() == 1 && args[0] == "off")
+	{
+		std::cout << "Turning OFF LED bar." << std::endl;
+		led_bar.all_off();
+	}
+	else
+	{
+		std::cout << "Unknown command." << std::endl;
+	}
+
+	return;
+}
+
+
+void button( const VStr &args )
+{
+	SG::Button button;
+
+	std::cout << "Waiting up to 5 seconds for button to be pushed down..." << std::endl;
+	bool result = button.wait_for_button_down(5000);
+	if (result == false)
+	{
+		std::cout << "Timeout!" << std::endl;
+	}
+
+	std::cout << "Waiting up to 5 seconds for button to be released..." << std::endl;
+	result = button.wait_for_button_up(5000);
+	if (result == false)
+	{
+		std::cout << "Timeout!" << std::endl;
+	}
+
+	bool was_up = false;
+	while ( exit_signal_detected == 0 )
+	{
+		std::this_thread::sleep_for( std::chrono::milliseconds(100) );
+
+		const bool is_up = button.is_up();
+
+		if (was_up != is_up)
+		{
+			std::cout << "Button is " << (is_up ? "up" : "down") << std::endl;
+			was_up = is_up;
+		}
+	}
+
+	return;
+}
+
+
 void show_help( void )
 {
 	std::cout	<< "Command line usage:"								<< std::endl
@@ -344,10 +522,15 @@ void show_help( void )
 				<< "  buzzer"											<< std::endl
 				<< "  chainable_rgb_led [r g b | html_colour]"			<< std::endl
 				<< "  temperature"										<< std::endl
+				<< "  compass"											<< std::endl
+				<< "  bb_detect"										<< std::endl
 				<< "  bb_led"											<< std::endl
+				<< "  bb_usb [on|off]"									<< std::endl
 				<< "  bb_watchdog"										<< std::endl
 				<< "  oled096 [on|off|normal|invert|all_on|all_off|contrast #|lock|unlock|scroll_start|scroll_stop|left #|right #]" << std::endl
 				<< "  oled112 [on|off|normal|invert|all_on|all_off|contrast #|lock|unlock|scroll_start|scroll_stop|left #|right #]" << std::endl
+				<< "  ledbar [on|off]"									<< std::endl
+				<< "  button"											<< std::endl
 				;
 
 	return;
@@ -388,10 +571,15 @@ int seeedgrove_example_application( int argc, char **argv )
 	else if (cmd == "chainable_rgb_led"	)	chainable_rgb_led	(args);
 	else if (cmd == "buzzer"			)	buzzer				(args);
 	else if (cmd == "temperature"		)	temperature			(args);
+	else if (cmd == "compass"			)	compass				(args);
+	else if (cmd == "bb_detect"			)	bb_detect			(args);
 	else if (cmd == "bb_led"			)	bb_led				(args);
 	else if (cmd == "bb_watchdog"		)	bb_watchdog			(args);
+	else if (cmd == "bb_usb"			)	bb_usb				(args);
 	else if (cmd == "oled096"			)	oled096				(args);
 	else if (cmd == "oled112"			)	oled112				(args);
+	else if (cmd == "ledbar"			)	ledbar				(args);
+	else if (cmd == "button"			)	button				(args);
 	else if (cmd == "help"				)	show_help();
 	else if (cmd == "--help"			)	show_help();
 	else if (cmd == ""					)	show_help();
